Documentation
¶
Index ¶
- Constants
- Variables
- func NewRuntimeServiceHandler(svc RuntimeServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)
- type ExecuteTTYRequest
- func (x *ExecuteTTYRequest) ClearCluster()
- func (x *ExecuteTTYRequest) ClearCols()
- func (x *ExecuteTTYRequest) ClearContainer()
- func (x *ExecuteTTYRequest) ClearName()
- func (x *ExecuteTTYRequest) ClearNamespace()
- func (x *ExecuteTTYRequest) ClearRows()
- func (x *ExecuteTTYRequest) ClearTty()
- func (x *ExecuteTTYRequest) GetCluster() string
- func (x *ExecuteTTYRequest) GetCols() uint32
- func (x *ExecuteTTYRequest) GetCommand() []string
- func (x *ExecuteTTYRequest) GetContainer() string
- func (x *ExecuteTTYRequest) GetName() string
- func (x *ExecuteTTYRequest) GetNamespace() string
- func (x *ExecuteTTYRequest) GetRows() uint32
- func (x *ExecuteTTYRequest) GetTty() bool
- func (x *ExecuteTTYRequest) HasCluster() bool
- func (x *ExecuteTTYRequest) HasCols() bool
- func (x *ExecuteTTYRequest) HasContainer() bool
- func (x *ExecuteTTYRequest) HasName() bool
- func (x *ExecuteTTYRequest) HasNamespace() bool
- func (x *ExecuteTTYRequest) HasRows() bool
- func (x *ExecuteTTYRequest) HasTty() bool
- func (*ExecuteTTYRequest) ProtoMessage()
- func (x *ExecuteTTYRequest) ProtoReflect() protoreflect.Message
- func (x *ExecuteTTYRequest) Reset()
- func (x *ExecuteTTYRequest) SetCluster(v string)
- func (x *ExecuteTTYRequest) SetCols(v uint32)
- func (x *ExecuteTTYRequest) SetCommand(v []string)
- func (x *ExecuteTTYRequest) SetContainer(v string)
- func (x *ExecuteTTYRequest) SetName(v string)
- func (x *ExecuteTTYRequest) SetNamespace(v string)
- func (x *ExecuteTTYRequest) SetRows(v uint32)
- func (x *ExecuteTTYRequest) SetTty(v bool)
- func (x *ExecuteTTYRequest) String() string
- type ExecuteTTYRequest_builder
- type ExecuteTTYResponse
- func (x *ExecuteTTYResponse) ClearSessionId()
- func (x *ExecuteTTYResponse) ClearStderr()
- func (x *ExecuteTTYResponse) ClearStdout()
- func (x *ExecuteTTYResponse) GetSessionId() string
- func (x *ExecuteTTYResponse) GetStderr() []byte
- func (x *ExecuteTTYResponse) GetStdout() []byte
- func (x *ExecuteTTYResponse) HasSessionId() bool
- func (x *ExecuteTTYResponse) HasStderr() bool
- func (x *ExecuteTTYResponse) HasStdout() bool
- func (*ExecuteTTYResponse) ProtoMessage()
- func (x *ExecuteTTYResponse) ProtoReflect() protoreflect.Message
- func (x *ExecuteTTYResponse) Reset()
- func (x *ExecuteTTYResponse) SetSessionId(v string)
- func (x *ExecuteTTYResponse) SetStderr(v []byte)
- func (x *ExecuteTTYResponse) SetStdout(v []byte)
- func (x *ExecuteTTYResponse) String() string
- type ExecuteTTYResponse_builder
- type PodLogRequest
- func (x *PodLogRequest) ClearCluster()
- func (x *PodLogRequest) ClearContainer()
- func (x *PodLogRequest) ClearFollow()
- func (x *PodLogRequest) ClearLimitBytes()
- func (x *PodLogRequest) ClearName()
- func (x *PodLogRequest) ClearNamespace()
- func (x *PodLogRequest) ClearPrevious()
- func (x *PodLogRequest) ClearSinceSeconds()
- func (x *PodLogRequest) ClearSinceTime()
- func (x *PodLogRequest) ClearTailLines()
- func (x *PodLogRequest) ClearTimestamps()
- func (x *PodLogRequest) GetCluster() string
- func (x *PodLogRequest) GetContainer() string
- func (x *PodLogRequest) GetFollow() bool
- func (x *PodLogRequest) GetLimitBytes() int64
- func (x *PodLogRequest) GetName() string
- func (x *PodLogRequest) GetNamespace() string
- func (x *PodLogRequest) GetPrevious() bool
- func (x *PodLogRequest) GetSinceSeconds() int64
- func (x *PodLogRequest) GetSinceTime() *timestamppb.Timestamp
- func (x *PodLogRequest) GetTailLines() int64
- func (x *PodLogRequest) GetTimestamps() bool
- func (x *PodLogRequest) HasCluster() bool
- func (x *PodLogRequest) HasContainer() bool
- func (x *PodLogRequest) HasFollow() bool
- func (x *PodLogRequest) HasLimitBytes() bool
- func (x *PodLogRequest) HasName() bool
- func (x *PodLogRequest) HasNamespace() bool
- func (x *PodLogRequest) HasPrevious() bool
- func (x *PodLogRequest) HasSinceSeconds() bool
- func (x *PodLogRequest) HasSinceTime() bool
- func (x *PodLogRequest) HasTailLines() bool
- func (x *PodLogRequest) HasTimestamps() bool
- func (*PodLogRequest) ProtoMessage()
- func (x *PodLogRequest) ProtoReflect() protoreflect.Message
- func (x *PodLogRequest) Reset()
- func (x *PodLogRequest) SetCluster(v string)
- func (x *PodLogRequest) SetContainer(v string)
- func (x *PodLogRequest) SetFollow(v bool)
- func (x *PodLogRequest) SetLimitBytes(v int64)
- func (x *PodLogRequest) SetName(v string)
- func (x *PodLogRequest) SetNamespace(v string)
- func (x *PodLogRequest) SetPrevious(v bool)
- func (x *PodLogRequest) SetSinceSeconds(v int64)
- func (x *PodLogRequest) SetSinceTime(v *timestamppb.Timestamp)
- func (x *PodLogRequest) SetTailLines(v int64)
- func (x *PodLogRequest) SetTimestamps(v bool)
- func (x *PodLogRequest) String() string
- type PodLogRequest_builder
- type PodLogResponse
- func (x *PodLogResponse) ClearData()
- func (x *PodLogResponse) GetData() []byte
- func (x *PodLogResponse) HasData() bool
- func (*PodLogResponse) ProtoMessage()
- func (x *PodLogResponse) ProtoReflect() protoreflect.Message
- func (x *PodLogResponse) Reset()
- func (x *PodLogResponse) SetData(v []byte)
- func (x *PodLogResponse) String() string
- type PodLogResponse_builder
- type PortForwardRequest
- func (x *PortForwardRequest) ClearCluster()
- func (x *PortForwardRequest) ClearName()
- func (x *PortForwardRequest) ClearNamespace()
- func (x *PortForwardRequest) ClearPort()
- func (x *PortForwardRequest) GetCluster() string
- func (x *PortForwardRequest) GetName() string
- func (x *PortForwardRequest) GetNamespace() string
- func (x *PortForwardRequest) GetPort() int32
- func (x *PortForwardRequest) HasCluster() bool
- func (x *PortForwardRequest) HasName() bool
- func (x *PortForwardRequest) HasNamespace() bool
- func (x *PortForwardRequest) HasPort() bool
- func (*PortForwardRequest) ProtoMessage()
- func (x *PortForwardRequest) ProtoReflect() protoreflect.Message
- func (x *PortForwardRequest) Reset()
- func (x *PortForwardRequest) SetCluster(v string)
- func (x *PortForwardRequest) SetName(v string)
- func (x *PortForwardRequest) SetNamespace(v string)
- func (x *PortForwardRequest) SetPort(v int32)
- func (x *PortForwardRequest) String() string
- type PortForwardRequest_builder
- type PortForwardResponse
- func (x *PortForwardResponse) ClearData()
- func (x *PortForwardResponse) ClearSessionId()
- func (x *PortForwardResponse) GetData() []byte
- func (x *PortForwardResponse) GetSessionId() string
- func (x *PortForwardResponse) HasData() bool
- func (x *PortForwardResponse) HasSessionId() bool
- func (*PortForwardResponse) ProtoMessage()
- func (x *PortForwardResponse) ProtoReflect() protoreflect.Message
- func (x *PortForwardResponse) Reset()
- func (x *PortForwardResponse) SetData(v []byte)
- func (x *PortForwardResponse) SetSessionId(v string)
- func (x *PortForwardResponse) String() string
- type PortForwardResponse_builder
- type ResizeTTYRequest
- func (x *ResizeTTYRequest) ClearCols()
- func (x *ResizeTTYRequest) ClearRows()
- func (x *ResizeTTYRequest) ClearSessionId()
- func (x *ResizeTTYRequest) GetCols() uint32
- func (x *ResizeTTYRequest) GetRows() uint32
- func (x *ResizeTTYRequest) GetSessionId() string
- func (x *ResizeTTYRequest) HasCols() bool
- func (x *ResizeTTYRequest) HasRows() bool
- func (x *ResizeTTYRequest) HasSessionId() bool
- func (*ResizeTTYRequest) ProtoMessage()
- func (x *ResizeTTYRequest) ProtoReflect() protoreflect.Message
- func (x *ResizeTTYRequest) Reset()
- func (x *ResizeTTYRequest) SetCols(v uint32)
- func (x *ResizeTTYRequest) SetRows(v uint32)
- func (x *ResizeTTYRequest) SetSessionId(v string)
- func (x *ResizeTTYRequest) String() string
- type ResizeTTYRequest_builder
- type RestartRequest
- func (x *RestartRequest) ClearCluster()
- func (x *RestartRequest) ClearGroup()
- func (x *RestartRequest) ClearName()
- func (x *RestartRequest) ClearNamespace()
- func (x *RestartRequest) ClearResource()
- func (x *RestartRequest) ClearVersion()
- func (x *RestartRequest) GetCluster() string
- func (x *RestartRequest) GetGroup() string
- func (x *RestartRequest) GetName() string
- func (x *RestartRequest) GetNamespace() string
- func (x *RestartRequest) GetResource() string
- func (x *RestartRequest) GetVersion() string
- func (x *RestartRequest) HasCluster() bool
- func (x *RestartRequest) HasGroup() bool
- func (x *RestartRequest) HasName() bool
- func (x *RestartRequest) HasNamespace() bool
- func (x *RestartRequest) HasResource() bool
- func (x *RestartRequest) HasVersion() bool
- func (*RestartRequest) ProtoMessage()
- func (x *RestartRequest) ProtoReflect() protoreflect.Message
- func (x *RestartRequest) Reset()
- func (x *RestartRequest) SetCluster(v string)
- func (x *RestartRequest) SetGroup(v string)
- func (x *RestartRequest) SetName(v string)
- func (x *RestartRequest) SetNamespace(v string)
- func (x *RestartRequest) SetResource(v string)
- func (x *RestartRequest) SetVersion(v string)
- func (x *RestartRequest) String() string
- type RestartRequest_builder
- type RuntimeServiceClient
- type RuntimeServiceHandler
- type ScaleRequest
- func (x *ScaleRequest) ClearCluster()
- func (x *ScaleRequest) ClearGroup()
- func (x *ScaleRequest) ClearName()
- func (x *ScaleRequest) ClearNamespace()
- func (x *ScaleRequest) ClearReplicas()
- func (x *ScaleRequest) ClearResource()
- func (x *ScaleRequest) ClearVersion()
- func (x *ScaleRequest) GetCluster() string
- func (x *ScaleRequest) GetGroup() string
- func (x *ScaleRequest) GetName() string
- func (x *ScaleRequest) GetNamespace() string
- func (x *ScaleRequest) GetReplicas() int32
- func (x *ScaleRequest) GetResource() string
- func (x *ScaleRequest) GetVersion() string
- func (x *ScaleRequest) HasCluster() bool
- func (x *ScaleRequest) HasGroup() bool
- func (x *ScaleRequest) HasName() bool
- func (x *ScaleRequest) HasNamespace() bool
- func (x *ScaleRequest) HasReplicas() bool
- func (x *ScaleRequest) HasResource() bool
- func (x *ScaleRequest) HasVersion() bool
- func (*ScaleRequest) ProtoMessage()
- func (x *ScaleRequest) ProtoReflect() protoreflect.Message
- func (x *ScaleRequest) Reset()
- func (x *ScaleRequest) SetCluster(v string)
- func (x *ScaleRequest) SetGroup(v string)
- func (x *ScaleRequest) SetName(v string)
- func (x *ScaleRequest) SetNamespace(v string)
- func (x *ScaleRequest) SetReplicas(v int32)
- func (x *ScaleRequest) SetResource(v string)
- func (x *ScaleRequest) SetVersion(v string)
- func (x *ScaleRequest) String() string
- type ScaleRequest_builder
- type ScaleResponse
- func (x *ScaleResponse) ClearReplicas()
- func (x *ScaleResponse) GetReplicas() int32
- func (x *ScaleResponse) HasReplicas() bool
- func (*ScaleResponse) ProtoMessage()
- func (x *ScaleResponse) ProtoReflect() protoreflect.Message
- func (x *ScaleResponse) Reset()
- func (x *ScaleResponse) SetReplicas(v int32)
- func (x *ScaleResponse) String() string
- type ScaleResponse_builder
- type UnimplementedRuntimeServiceHandler
- func (UnimplementedRuntimeServiceHandler) ExecuteTTY(context.Context, *ExecuteTTYRequest, *connect.ServerStream[ExecuteTTYResponse]) error
- func (UnimplementedRuntimeServiceHandler) PodLog(context.Context, *PodLogRequest, *connect.ServerStream[PodLogResponse]) error
- func (UnimplementedRuntimeServiceHandler) PortForward(context.Context, *PortForwardRequest, ...) error
- func (UnimplementedRuntimeServiceHandler) ResizeTTY(context.Context, *ResizeTTYRequest) (*emptypb.Empty, error)
- func (UnimplementedRuntimeServiceHandler) Restart(context.Context, *RestartRequest) (*emptypb.Empty, error)
- func (UnimplementedRuntimeServiceHandler) Scale(context.Context, *ScaleRequest) (*ScaleResponse, error)
- func (UnimplementedRuntimeServiceHandler) WritePortForward(context.Context, *WritePortForwardRequest) (*emptypb.Empty, error)
- func (UnimplementedRuntimeServiceHandler) WriteTTY(context.Context, *WriteTTYRequest) (*emptypb.Empty, error)
- type WritePortForwardRequest
- func (x *WritePortForwardRequest) ClearData()
- func (x *WritePortForwardRequest) ClearSessionId()
- func (x *WritePortForwardRequest) GetData() []byte
- func (x *WritePortForwardRequest) GetSessionId() string
- func (x *WritePortForwardRequest) HasData() bool
- func (x *WritePortForwardRequest) HasSessionId() bool
- func (*WritePortForwardRequest) ProtoMessage()
- func (x *WritePortForwardRequest) ProtoReflect() protoreflect.Message
- func (x *WritePortForwardRequest) Reset()
- func (x *WritePortForwardRequest) SetData(v []byte)
- func (x *WritePortForwardRequest) SetSessionId(v string)
- func (x *WritePortForwardRequest) String() string
- type WritePortForwardRequest_builder
- type WriteTTYRequest
- func (x *WriteTTYRequest) ClearSessionId()
- func (x *WriteTTYRequest) ClearStdin()
- func (x *WriteTTYRequest) GetSessionId() string
- func (x *WriteTTYRequest) GetStdin() []byte
- func (x *WriteTTYRequest) HasSessionId() bool
- func (x *WriteTTYRequest) HasStdin() bool
- func (*WriteTTYRequest) ProtoMessage()
- func (x *WriteTTYRequest) ProtoReflect() protoreflect.Message
- func (x *WriteTTYRequest) Reset()
- func (x *WriteTTYRequest) SetSessionId(v string)
- func (x *WriteTTYRequest) SetStdin(v []byte)
- func (x *WriteTTYRequest) String() string
- type WriteTTYRequest_builder
Constants ¶
const ( // RuntimeServicePodLogProcedure is the fully-qualified name of the RuntimeService's PodLog RPC. RuntimeServicePodLogProcedure = "/otterscale.runtime.v1.RuntimeService/PodLog" // RuntimeServiceExecuteTTYProcedure is the fully-qualified name of the RuntimeService's ExecuteTTY // RPC. RuntimeServiceExecuteTTYProcedure = "/otterscale.runtime.v1.RuntimeService/ExecuteTTY" // RuntimeServiceWriteTTYProcedure is the fully-qualified name of the RuntimeService's WriteTTY RPC. RuntimeServiceWriteTTYProcedure = "/otterscale.runtime.v1.RuntimeService/WriteTTY" // RuntimeServiceResizeTTYProcedure is the fully-qualified name of the RuntimeService's ResizeTTY // RPC. RuntimeServiceResizeTTYProcedure = "/otterscale.runtime.v1.RuntimeService/ResizeTTY" // RuntimeServicePortForwardProcedure is the fully-qualified name of the RuntimeService's // PortForward RPC. RuntimeServicePortForwardProcedure = "/otterscale.runtime.v1.RuntimeService/PortForward" // RuntimeServiceWritePortForwardProcedure is the fully-qualified name of the RuntimeService's // WritePortForward RPC. RuntimeServiceWritePortForwardProcedure = "/otterscale.runtime.v1.RuntimeService/WritePortForward" // RuntimeServiceScaleProcedure is the fully-qualified name of the RuntimeService's Scale RPC. RuntimeServiceScaleProcedure = "/otterscale.runtime.v1.RuntimeService/Scale" // RuntimeServiceRestartProcedure is the fully-qualified name of the RuntimeService's Restart RPC. RuntimeServiceRestartProcedure = "/otterscale.runtime.v1.RuntimeService/Restart" )
These constants are the fully-qualified names of the RPCs defined in this package. They're exposed at runtime as Spec.Procedure and as the final two segments of the HTTP route.
Note that these are different from the fully-qualified method names used by google.golang.org/protobuf/reflect/protoreflect. To convert from these constants to reflection-formatted method names, remove the leading slash and convert the remaining slash to a period.
const (
// RuntimeServiceName is the fully-qualified name of the RuntimeService service.
RuntimeServiceName = "otterscale.runtime.v1.RuntimeService"
)
Variables ¶
var File_runtime_v1_runtime_proto protoreflect.FileDescriptor
Functions ¶
func NewRuntimeServiceHandler ¶
func NewRuntimeServiceHandler(svc RuntimeServiceHandler, opts ...connect.HandlerOption) (string, http.Handler)
NewRuntimeServiceHandler builds an HTTP handler from the service implementation. It returns the path on which to mount the handler and the handler itself.
By default, handlers support the Connect, gRPC, and gRPC-Web protocols with the binary Protobuf and JSON codecs. They also support gzip compression.
Types ¶
type ExecuteTTYRequest ¶
type ExecuteTTYRequest struct {
XXX_raceDetectHookData protoimpl.RaceDetectHookData
XXX_presence [1]uint32
// contains filtered or unexported fields
}
ExecuteTTYRequest defines the parameters for starting an interactive exec session in a container. Fields align with corev1.PodExecOptions.
func (*ExecuteTTYRequest) ClearCluster ¶
func (x *ExecuteTTYRequest) ClearCluster()
func (*ExecuteTTYRequest) ClearCols ¶
func (x *ExecuteTTYRequest) ClearCols()
func (*ExecuteTTYRequest) ClearContainer ¶
func (x *ExecuteTTYRequest) ClearContainer()
func (*ExecuteTTYRequest) ClearName ¶
func (x *ExecuteTTYRequest) ClearName()
func (*ExecuteTTYRequest) ClearNamespace ¶
func (x *ExecuteTTYRequest) ClearNamespace()
func (*ExecuteTTYRequest) ClearRows ¶
func (x *ExecuteTTYRequest) ClearRows()
func (*ExecuteTTYRequest) ClearTty ¶
func (x *ExecuteTTYRequest) ClearTty()
func (*ExecuteTTYRequest) GetCluster ¶
func (x *ExecuteTTYRequest) GetCluster() string
func (*ExecuteTTYRequest) GetCols ¶
func (x *ExecuteTTYRequest) GetCols() uint32
func (*ExecuteTTYRequest) GetCommand ¶
func (x *ExecuteTTYRequest) GetCommand() []string
func (*ExecuteTTYRequest) GetContainer ¶
func (x *ExecuteTTYRequest) GetContainer() string
func (*ExecuteTTYRequest) GetName ¶
func (x *ExecuteTTYRequest) GetName() string
func (*ExecuteTTYRequest) GetNamespace ¶
func (x *ExecuteTTYRequest) GetNamespace() string
func (*ExecuteTTYRequest) GetRows ¶
func (x *ExecuteTTYRequest) GetRows() uint32
func (*ExecuteTTYRequest) GetTty ¶
func (x *ExecuteTTYRequest) GetTty() bool
func (*ExecuteTTYRequest) HasCluster ¶
func (x *ExecuteTTYRequest) HasCluster() bool
func (*ExecuteTTYRequest) HasCols ¶
func (x *ExecuteTTYRequest) HasCols() bool
func (*ExecuteTTYRequest) HasContainer ¶
func (x *ExecuteTTYRequest) HasContainer() bool
func (*ExecuteTTYRequest) HasName ¶
func (x *ExecuteTTYRequest) HasName() bool
func (*ExecuteTTYRequest) HasNamespace ¶
func (x *ExecuteTTYRequest) HasNamespace() bool
func (*ExecuteTTYRequest) HasRows ¶
func (x *ExecuteTTYRequest) HasRows() bool
func (*ExecuteTTYRequest) HasTty ¶
func (x *ExecuteTTYRequest) HasTty() bool
func (*ExecuteTTYRequest) ProtoMessage ¶
func (*ExecuteTTYRequest) ProtoMessage()
func (*ExecuteTTYRequest) ProtoReflect ¶
func (x *ExecuteTTYRequest) ProtoReflect() protoreflect.Message
func (*ExecuteTTYRequest) Reset ¶
func (x *ExecuteTTYRequest) Reset()
func (*ExecuteTTYRequest) SetCluster ¶
func (x *ExecuteTTYRequest) SetCluster(v string)
func (*ExecuteTTYRequest) SetCols ¶
func (x *ExecuteTTYRequest) SetCols(v uint32)
func (*ExecuteTTYRequest) SetCommand ¶
func (x *ExecuteTTYRequest) SetCommand(v []string)
func (*ExecuteTTYRequest) SetContainer ¶
func (x *ExecuteTTYRequest) SetContainer(v string)
func (*ExecuteTTYRequest) SetName ¶
func (x *ExecuteTTYRequest) SetName(v string)
func (*ExecuteTTYRequest) SetNamespace ¶
func (x *ExecuteTTYRequest) SetNamespace(v string)
func (*ExecuteTTYRequest) SetRows ¶
func (x *ExecuteTTYRequest) SetRows(v uint32)
func (*ExecuteTTYRequest) SetTty ¶
func (x *ExecuteTTYRequest) SetTty(v bool)
func (*ExecuteTTYRequest) String ¶
func (x *ExecuteTTYRequest) String() string
type ExecuteTTYRequest_builder ¶
type ExecuteTTYRequest_builder struct {
// The target Kubernetes cluster identifier.
Cluster *string
// The namespace of the pod.
Namespace *string
// The name of the pod.
Name *string
// The container to exec into. If omitted, the first container is used.
Container *string
// The command to execute (e.g. ["/bin/sh"]).
Command []string
// If true, allocate a TTY for the exec session.
Tty *bool
// Initial terminal height in rows.
Rows *uint32
// Initial terminal width in columns.
Cols *uint32
// contains filtered or unexported fields
}
func (ExecuteTTYRequest_builder) Build ¶
func (b0 ExecuteTTYRequest_builder) Build() *ExecuteTTYRequest
type ExecuteTTYResponse ¶
type ExecuteTTYResponse struct {
XXX_raceDetectHookData protoimpl.RaceDetectHookData
XXX_presence [1]uint32
// contains filtered or unexported fields
}
ExecuteTTYResponse streams output from the exec session.
func (*ExecuteTTYResponse) ClearSessionId ¶
func (x *ExecuteTTYResponse) ClearSessionId()
func (*ExecuteTTYResponse) ClearStderr ¶
func (x *ExecuteTTYResponse) ClearStderr()
func (*ExecuteTTYResponse) ClearStdout ¶
func (x *ExecuteTTYResponse) ClearStdout()
func (*ExecuteTTYResponse) GetSessionId ¶
func (x *ExecuteTTYResponse) GetSessionId() string
func (*ExecuteTTYResponse) GetStderr ¶
func (x *ExecuteTTYResponse) GetStderr() []byte
func (*ExecuteTTYResponse) GetStdout ¶
func (x *ExecuteTTYResponse) GetStdout() []byte
func (*ExecuteTTYResponse) HasSessionId ¶
func (x *ExecuteTTYResponse) HasSessionId() bool
func (*ExecuteTTYResponse) HasStderr ¶
func (x *ExecuteTTYResponse) HasStderr() bool
func (*ExecuteTTYResponse) HasStdout ¶
func (x *ExecuteTTYResponse) HasStdout() bool
func (*ExecuteTTYResponse) ProtoMessage ¶
func (*ExecuteTTYResponse) ProtoMessage()
func (*ExecuteTTYResponse) ProtoReflect ¶
func (x *ExecuteTTYResponse) ProtoReflect() protoreflect.Message
func (*ExecuteTTYResponse) Reset ¶
func (x *ExecuteTTYResponse) Reset()
func (*ExecuteTTYResponse) SetSessionId ¶
func (x *ExecuteTTYResponse) SetSessionId(v string)
func (*ExecuteTTYResponse) SetStderr ¶
func (x *ExecuteTTYResponse) SetStderr(v []byte)
func (*ExecuteTTYResponse) SetStdout ¶
func (x *ExecuteTTYResponse) SetStdout(v []byte)
func (*ExecuteTTYResponse) String ¶
func (x *ExecuteTTYResponse) String() string
type ExecuteTTYResponse_builder ¶
type ExecuteTTYResponse_builder struct {
// The session identifier, set only in the first response message.
// Subsequent WriteTTY / ResizeTTY calls must reference this ID.
SessionId *string
// Stdout data from the exec session.
Stdout []byte
// Stderr data from the exec session (only when tty is false).
Stderr []byte
// contains filtered or unexported fields
}
func (ExecuteTTYResponse_builder) Build ¶
func (b0 ExecuteTTYResponse_builder) Build() *ExecuteTTYResponse
type PodLogRequest ¶
type PodLogRequest struct {
XXX_raceDetectHookData protoimpl.RaceDetectHookData
XXX_presence [1]uint32
// contains filtered or unexported fields
}
PodLogRequest defines the parameters for streaming container logs. Fields align with corev1.PodLogOptions.
func (*PodLogRequest) ClearCluster ¶
func (x *PodLogRequest) ClearCluster()
func (*PodLogRequest) ClearContainer ¶
func (x *PodLogRequest) ClearContainer()
func (*PodLogRequest) ClearFollow ¶
func (x *PodLogRequest) ClearFollow()
func (*PodLogRequest) ClearLimitBytes ¶
func (x *PodLogRequest) ClearLimitBytes()
func (*PodLogRequest) ClearName ¶
func (x *PodLogRequest) ClearName()
func (*PodLogRequest) ClearNamespace ¶
func (x *PodLogRequest) ClearNamespace()
func (*PodLogRequest) ClearPrevious ¶
func (x *PodLogRequest) ClearPrevious()
func (*PodLogRequest) ClearSinceSeconds ¶
func (x *PodLogRequest) ClearSinceSeconds()
func (*PodLogRequest) ClearSinceTime ¶
func (x *PodLogRequest) ClearSinceTime()
func (*PodLogRequest) ClearTailLines ¶
func (x *PodLogRequest) ClearTailLines()
func (*PodLogRequest) ClearTimestamps ¶
func (x *PodLogRequest) ClearTimestamps()
func (*PodLogRequest) GetCluster ¶
func (x *PodLogRequest) GetCluster() string
func (*PodLogRequest) GetContainer ¶
func (x *PodLogRequest) GetContainer() string
func (*PodLogRequest) GetFollow ¶
func (x *PodLogRequest) GetFollow() bool
func (*PodLogRequest) GetLimitBytes ¶
func (x *PodLogRequest) GetLimitBytes() int64
func (*PodLogRequest) GetName ¶
func (x *PodLogRequest) GetName() string
func (*PodLogRequest) GetNamespace ¶
func (x *PodLogRequest) GetNamespace() string
func (*PodLogRequest) GetPrevious ¶
func (x *PodLogRequest) GetPrevious() bool
func (*PodLogRequest) GetSinceSeconds ¶
func (x *PodLogRequest) GetSinceSeconds() int64
func (*PodLogRequest) GetSinceTime ¶
func (x *PodLogRequest) GetSinceTime() *timestamppb.Timestamp
func (*PodLogRequest) GetTailLines ¶
func (x *PodLogRequest) GetTailLines() int64
func (*PodLogRequest) GetTimestamps ¶
func (x *PodLogRequest) GetTimestamps() bool
func (*PodLogRequest) HasCluster ¶
func (x *PodLogRequest) HasCluster() bool
func (*PodLogRequest) HasContainer ¶
func (x *PodLogRequest) HasContainer() bool
func (*PodLogRequest) HasFollow ¶
func (x *PodLogRequest) HasFollow() bool
func (*PodLogRequest) HasLimitBytes ¶
func (x *PodLogRequest) HasLimitBytes() bool
func (*PodLogRequest) HasName ¶
func (x *PodLogRequest) HasName() bool
func (*PodLogRequest) HasNamespace ¶
func (x *PodLogRequest) HasNamespace() bool
func (*PodLogRequest) HasPrevious ¶
func (x *PodLogRequest) HasPrevious() bool
func (*PodLogRequest) HasSinceSeconds ¶
func (x *PodLogRequest) HasSinceSeconds() bool
func (*PodLogRequest) HasSinceTime ¶
func (x *PodLogRequest) HasSinceTime() bool
func (*PodLogRequest) HasTailLines ¶
func (x *PodLogRequest) HasTailLines() bool
func (*PodLogRequest) HasTimestamps ¶
func (x *PodLogRequest) HasTimestamps() bool
func (*PodLogRequest) ProtoMessage ¶
func (*PodLogRequest) ProtoMessage()
func (*PodLogRequest) ProtoReflect ¶
func (x *PodLogRequest) ProtoReflect() protoreflect.Message
func (*PodLogRequest) Reset ¶
func (x *PodLogRequest) Reset()
func (*PodLogRequest) SetCluster ¶
func (x *PodLogRequest) SetCluster(v string)
func (*PodLogRequest) SetContainer ¶
func (x *PodLogRequest) SetContainer(v string)
func (*PodLogRequest) SetFollow ¶
func (x *PodLogRequest) SetFollow(v bool)
func (*PodLogRequest) SetLimitBytes ¶
func (x *PodLogRequest) SetLimitBytes(v int64)
func (*PodLogRequest) SetName ¶
func (x *PodLogRequest) SetName(v string)
func (*PodLogRequest) SetNamespace ¶
func (x *PodLogRequest) SetNamespace(v string)
func (*PodLogRequest) SetPrevious ¶
func (x *PodLogRequest) SetPrevious(v bool)
func (*PodLogRequest) SetSinceSeconds ¶
func (x *PodLogRequest) SetSinceSeconds(v int64)
func (*PodLogRequest) SetSinceTime ¶
func (x *PodLogRequest) SetSinceTime(v *timestamppb.Timestamp)
func (*PodLogRequest) SetTailLines ¶
func (x *PodLogRequest) SetTailLines(v int64)
func (*PodLogRequest) SetTimestamps ¶
func (x *PodLogRequest) SetTimestamps(v bool)
func (*PodLogRequest) String ¶
func (x *PodLogRequest) String() string
type PodLogRequest_builder ¶
type PodLogRequest_builder struct {
// The target Kubernetes cluster identifier.
Cluster *string
// The namespace of the pod.
Namespace *string
// The name of the pod.
Name *string
// The container name. If omitted, the first container in the pod is used.
Container *string
// If true, stream logs as they are produced (like `kubectl logs -f`).
Follow *bool
// Number of lines from the end of the logs to show. If not set, all logs are shown.
TailLines *int64
// A relative time in seconds before the current time from which to show logs.
SinceSeconds *int64
// An absolute time from which to show logs. Mutually exclusive with since_seconds.
SinceTime *timestamppb.Timestamp
// If true, return the logs for the previous terminated container instance.
Previous *bool
// If true, add an RFC3339 timestamp at the beginning of every line of log output.
Timestamps *bool
// Limit the number of bytes returned from the server.
LimitBytes *int64
// contains filtered or unexported fields
}
func (PodLogRequest_builder) Build ¶
func (b0 PodLogRequest_builder) Build() *PodLogRequest
type PodLogResponse ¶
type PodLogResponse struct {
XXX_raceDetectHookData protoimpl.RaceDetectHookData
XXX_presence [1]uint32
// contains filtered or unexported fields
}
PodLogResponse contains a chunk of log data.
func (*PodLogResponse) ClearData ¶
func (x *PodLogResponse) ClearData()
func (*PodLogResponse) GetData ¶
func (x *PodLogResponse) GetData() []byte
func (*PodLogResponse) HasData ¶
func (x *PodLogResponse) HasData() bool
func (*PodLogResponse) ProtoMessage ¶
func (*PodLogResponse) ProtoMessage()
func (*PodLogResponse) ProtoReflect ¶
func (x *PodLogResponse) ProtoReflect() protoreflect.Message
func (*PodLogResponse) Reset ¶
func (x *PodLogResponse) Reset()
func (*PodLogResponse) SetData ¶
func (x *PodLogResponse) SetData(v []byte)
func (*PodLogResponse) String ¶
func (x *PodLogResponse) String() string
type PodLogResponse_builder ¶
type PodLogResponse_builder struct {
// Raw log data bytes.
Data []byte
// contains filtered or unexported fields
}
func (PodLogResponse_builder) Build ¶
func (b0 PodLogResponse_builder) Build() *PodLogResponse
type PortForwardRequest ¶
type PortForwardRequest struct {
XXX_raceDetectHookData protoimpl.RaceDetectHookData
XXX_presence [1]uint32
// contains filtered or unexported fields
}
PortForwardRequest defines the parameters for starting a port-forward session.
func (*PortForwardRequest) ClearCluster ¶
func (x *PortForwardRequest) ClearCluster()
func (*PortForwardRequest) ClearName ¶
func (x *PortForwardRequest) ClearName()
func (*PortForwardRequest) ClearNamespace ¶
func (x *PortForwardRequest) ClearNamespace()
func (*PortForwardRequest) ClearPort ¶
func (x *PortForwardRequest) ClearPort()
func (*PortForwardRequest) GetCluster ¶
func (x *PortForwardRequest) GetCluster() string
func (*PortForwardRequest) GetName ¶
func (x *PortForwardRequest) GetName() string
func (*PortForwardRequest) GetNamespace ¶
func (x *PortForwardRequest) GetNamespace() string
func (*PortForwardRequest) GetPort ¶
func (x *PortForwardRequest) GetPort() int32
func (*PortForwardRequest) HasCluster ¶
func (x *PortForwardRequest) HasCluster() bool
func (*PortForwardRequest) HasName ¶
func (x *PortForwardRequest) HasName() bool
func (*PortForwardRequest) HasNamespace ¶
func (x *PortForwardRequest) HasNamespace() bool
func (*PortForwardRequest) HasPort ¶
func (x *PortForwardRequest) HasPort() bool
func (*PortForwardRequest) ProtoMessage ¶
func (*PortForwardRequest) ProtoMessage()
func (*PortForwardRequest) ProtoReflect ¶
func (x *PortForwardRequest) ProtoReflect() protoreflect.Message
func (*PortForwardRequest) Reset ¶
func (x *PortForwardRequest) Reset()
func (*PortForwardRequest) SetCluster ¶
func (x *PortForwardRequest) SetCluster(v string)
func (*PortForwardRequest) SetName ¶
func (x *PortForwardRequest) SetName(v string)
func (*PortForwardRequest) SetNamespace ¶
func (x *PortForwardRequest) SetNamespace(v string)
func (*PortForwardRequest) SetPort ¶
func (x *PortForwardRequest) SetPort(v int32)
func (*PortForwardRequest) String ¶
func (x *PortForwardRequest) String() string
type PortForwardRequest_builder ¶
type PortForwardRequest_builder struct {
// The target Kubernetes cluster identifier.
Cluster *string
// The namespace of the pod.
Namespace *string
// The name of the pod.
Name *string
// The container port to forward to.
Port *int32
// contains filtered or unexported fields
}
func (PortForwardRequest_builder) Build ¶
func (b0 PortForwardRequest_builder) Build() *PortForwardRequest
type PortForwardResponse ¶
type PortForwardResponse struct {
XXX_raceDetectHookData protoimpl.RaceDetectHookData
XXX_presence [1]uint32
// contains filtered or unexported fields
}
PortForwardResponse streams data received from the forwarded port.
func (*PortForwardResponse) ClearData ¶
func (x *PortForwardResponse) ClearData()
func (*PortForwardResponse) ClearSessionId ¶
func (x *PortForwardResponse) ClearSessionId()
func (*PortForwardResponse) GetData ¶
func (x *PortForwardResponse) GetData() []byte
func (*PortForwardResponse) GetSessionId ¶
func (x *PortForwardResponse) GetSessionId() string
func (*PortForwardResponse) HasData ¶
func (x *PortForwardResponse) HasData() bool
func (*PortForwardResponse) HasSessionId ¶
func (x *PortForwardResponse) HasSessionId() bool
func (*PortForwardResponse) ProtoMessage ¶
func (*PortForwardResponse) ProtoMessage()
func (*PortForwardResponse) ProtoReflect ¶
func (x *PortForwardResponse) ProtoReflect() protoreflect.Message
func (*PortForwardResponse) Reset ¶
func (x *PortForwardResponse) Reset()
func (*PortForwardResponse) SetData ¶
func (x *PortForwardResponse) SetData(v []byte)
func (*PortForwardResponse) SetSessionId ¶
func (x *PortForwardResponse) SetSessionId(v string)
func (*PortForwardResponse) String ¶
func (x *PortForwardResponse) String() string
type PortForwardResponse_builder ¶
type PortForwardResponse_builder struct {
// The session identifier, set only in the first response message.
// Subsequent WritePortForward calls must reference this ID.
SessionId *string
// Data received from the forwarded port on the pod.
Data []byte
// contains filtered or unexported fields
}
func (PortForwardResponse_builder) Build ¶
func (b0 PortForwardResponse_builder) Build() *PortForwardResponse
type ResizeTTYRequest ¶
type ResizeTTYRequest struct {
XXX_raceDetectHookData protoimpl.RaceDetectHookData
XXX_presence [1]uint32
// contains filtered or unexported fields
}
ResizeTTYRequest updates the terminal dimensions of an exec session.
func (*ResizeTTYRequest) ClearCols ¶
func (x *ResizeTTYRequest) ClearCols()
func (*ResizeTTYRequest) ClearRows ¶
func (x *ResizeTTYRequest) ClearRows()
func (*ResizeTTYRequest) ClearSessionId ¶
func (x *ResizeTTYRequest) ClearSessionId()
func (*ResizeTTYRequest) GetCols ¶
func (x *ResizeTTYRequest) GetCols() uint32
func (*ResizeTTYRequest) GetRows ¶
func (x *ResizeTTYRequest) GetRows() uint32
func (*ResizeTTYRequest) GetSessionId ¶
func (x *ResizeTTYRequest) GetSessionId() string
func (*ResizeTTYRequest) HasCols ¶
func (x *ResizeTTYRequest) HasCols() bool
func (*ResizeTTYRequest) HasRows ¶
func (x *ResizeTTYRequest) HasRows() bool
func (*ResizeTTYRequest) HasSessionId ¶
func (x *ResizeTTYRequest) HasSessionId() bool
func (*ResizeTTYRequest) ProtoMessage ¶
func (*ResizeTTYRequest) ProtoMessage()
func (*ResizeTTYRequest) ProtoReflect ¶
func (x *ResizeTTYRequest) ProtoReflect() protoreflect.Message
func (*ResizeTTYRequest) Reset ¶
func (x *ResizeTTYRequest) Reset()
func (*ResizeTTYRequest) SetCols ¶
func (x *ResizeTTYRequest) SetCols(v uint32)
func (*ResizeTTYRequest) SetRows ¶
func (x *ResizeTTYRequest) SetRows(v uint32)
func (*ResizeTTYRequest) SetSessionId ¶
func (x *ResizeTTYRequest) SetSessionId(v string)
func (*ResizeTTYRequest) String ¶
func (x *ResizeTTYRequest) String() string
type ResizeTTYRequest_builder ¶
type ResizeTTYRequest_builder struct {
// The session identifier returned in the first ExecuteTTYResponse.
SessionId *string
// New terminal height in rows.
Rows *uint32
// New terminal width in columns.
Cols *uint32
// contains filtered or unexported fields
}
func (ResizeTTYRequest_builder) Build ¶
func (b0 ResizeTTYRequest_builder) Build() *ResizeTTYRequest
type RestartRequest ¶
type RestartRequest struct {
XXX_raceDetectHookData protoimpl.RaceDetectHookData
XXX_presence [1]uint32
// contains filtered or unexported fields
}
RestartRequest defines the parameters for triggering a rolling restart. This patches the pod template annotation with kubectl.kubernetes.io/restartedAt, equivalent to `kubectl rollout restart`.
func (*RestartRequest) ClearCluster ¶
func (x *RestartRequest) ClearCluster()
func (*RestartRequest) ClearGroup ¶
func (x *RestartRequest) ClearGroup()
func (*RestartRequest) ClearName ¶
func (x *RestartRequest) ClearName()
func (*RestartRequest) ClearNamespace ¶
func (x *RestartRequest) ClearNamespace()
func (*RestartRequest) ClearResource ¶
func (x *RestartRequest) ClearResource()
func (*RestartRequest) ClearVersion ¶
func (x *RestartRequest) ClearVersion()
func (*RestartRequest) GetCluster ¶
func (x *RestartRequest) GetCluster() string
func (*RestartRequest) GetGroup ¶
func (x *RestartRequest) GetGroup() string
func (*RestartRequest) GetName ¶
func (x *RestartRequest) GetName() string
func (*RestartRequest) GetNamespace ¶
func (x *RestartRequest) GetNamespace() string
func (*RestartRequest) GetResource ¶
func (x *RestartRequest) GetResource() string
func (*RestartRequest) GetVersion ¶
func (x *RestartRequest) GetVersion() string
func (*RestartRequest) HasCluster ¶
func (x *RestartRequest) HasCluster() bool
func (*RestartRequest) HasGroup ¶
func (x *RestartRequest) HasGroup() bool
func (*RestartRequest) HasName ¶
func (x *RestartRequest) HasName() bool
func (*RestartRequest) HasNamespace ¶
func (x *RestartRequest) HasNamespace() bool
func (*RestartRequest) HasResource ¶
func (x *RestartRequest) HasResource() bool
func (*RestartRequest) HasVersion ¶
func (x *RestartRequest) HasVersion() bool
func (*RestartRequest) ProtoMessage ¶
func (*RestartRequest) ProtoMessage()
func (*RestartRequest) ProtoReflect ¶
func (x *RestartRequest) ProtoReflect() protoreflect.Message
func (*RestartRequest) Reset ¶
func (x *RestartRequest) Reset()
func (*RestartRequest) SetCluster ¶
func (x *RestartRequest) SetCluster(v string)
func (*RestartRequest) SetGroup ¶
func (x *RestartRequest) SetGroup(v string)
func (*RestartRequest) SetName ¶
func (x *RestartRequest) SetName(v string)
func (*RestartRequest) SetNamespace ¶
func (x *RestartRequest) SetNamespace(v string)
func (*RestartRequest) SetResource ¶
func (x *RestartRequest) SetResource(v string)
func (*RestartRequest) SetVersion ¶
func (x *RestartRequest) SetVersion(v string)
func (*RestartRequest) String ¶
func (x *RestartRequest) String() string
type RestartRequest_builder ¶
type RestartRequest_builder struct {
// The target Kubernetes cluster identifier.
Cluster *string
// Kubernetes API Group (e.g., "apps").
Group *string
// Kubernetes API Version (e.g., "v1").
Version *string
// Kubernetes API Resource name in plural (e.g., "deployments").
Resource *string
// The namespace of the workload.
Namespace *string
// The name of the workload.
Name *string
// contains filtered or unexported fields
}
func (RestartRequest_builder) Build ¶
func (b0 RestartRequest_builder) Build() *RestartRequest
type RuntimeServiceClient ¶
type RuntimeServiceClient interface {
// PodLog streams log output from a container, similar to `kubectl logs -f`.
PodLog(context.Context, *PodLogRequest) (*connect.ServerStreamForClient[PodLogResponse], error)
// ExecuteTTY starts an interactive exec session in a container and streams
// stdout/stderr back. Due to browser limitations, bidirectional streaming
// cannot be used; stdin is sent via the separate WriteTTY RPC.
ExecuteTTY(context.Context, *ExecuteTTYRequest) (*connect.ServerStreamForClient[ExecuteTTYResponse], error)
// WriteTTY sends stdin data to an active exec session identified by session_id.
WriteTTY(context.Context, *WriteTTYRequest) (*emptypb.Empty, error)
// ResizeTTY updates the terminal dimensions of an active exec session.
ResizeTTY(context.Context, *ResizeTTYRequest) (*emptypb.Empty, error)
// PortForward opens a port-forward session to a pod and streams data back.
// Due to browser limitations, bidirectional streaming cannot be used;
// data to the pod is sent via the separate WritePortForward RPC.
PortForward(context.Context, *PortForwardRequest) (*connect.ServerStreamForClient[PortForwardResponse], error)
// WritePortForward sends data to an active port-forward session.
WritePortForward(context.Context, *WritePortForwardRequest) (*emptypb.Empty, error)
// Scale updates the replica count of a scalable workload
// (Deployment, StatefulSet, ReplicaSet) via the /scale subresource.
Scale(context.Context, *ScaleRequest) (*ScaleResponse, error)
// Restart triggers a rolling restart of a workload by patching the
// pod template annotation, equivalent to `kubectl rollout restart`.
Restart(context.Context, *RestartRequest) (*emptypb.Empty, error)
}
RuntimeServiceClient is a client for the otterscale.runtime.v1.RuntimeService service.
func NewRuntimeServiceClient ¶
func NewRuntimeServiceClient(httpClient connect.HTTPClient, baseURL string, opts ...connect.ClientOption) RuntimeServiceClient
NewRuntimeServiceClient constructs a client for the otterscale.runtime.v1.RuntimeService service. By default, it uses the Connect protocol with the binary Protobuf Codec, asks for gzipped responses, and sends uncompressed requests. To use the gRPC or gRPC-Web protocols, supply the connect.WithGRPC() or connect.WithGRPCWeb() options.
The URL supplied here should be the base URL for the Connect or gRPC server (for example, http://api.acme.com or https://acme.com/grpc).
type RuntimeServiceHandler ¶
type RuntimeServiceHandler interface {
// PodLog streams log output from a container, similar to `kubectl logs -f`.
PodLog(context.Context, *PodLogRequest, *connect.ServerStream[PodLogResponse]) error
// ExecuteTTY starts an interactive exec session in a container and streams
// stdout/stderr back. Due to browser limitations, bidirectional streaming
// cannot be used; stdin is sent via the separate WriteTTY RPC.
ExecuteTTY(context.Context, *ExecuteTTYRequest, *connect.ServerStream[ExecuteTTYResponse]) error
// WriteTTY sends stdin data to an active exec session identified by session_id.
WriteTTY(context.Context, *WriteTTYRequest) (*emptypb.Empty, error)
// ResizeTTY updates the terminal dimensions of an active exec session.
ResizeTTY(context.Context, *ResizeTTYRequest) (*emptypb.Empty, error)
// PortForward opens a port-forward session to a pod and streams data back.
// Due to browser limitations, bidirectional streaming cannot be used;
// data to the pod is sent via the separate WritePortForward RPC.
PortForward(context.Context, *PortForwardRequest, *connect.ServerStream[PortForwardResponse]) error
// WritePortForward sends data to an active port-forward session.
WritePortForward(context.Context, *WritePortForwardRequest) (*emptypb.Empty, error)
// Scale updates the replica count of a scalable workload
// (Deployment, StatefulSet, ReplicaSet) via the /scale subresource.
Scale(context.Context, *ScaleRequest) (*ScaleResponse, error)
// Restart triggers a rolling restart of a workload by patching the
// pod template annotation, equivalent to `kubectl rollout restart`.
Restart(context.Context, *RestartRequest) (*emptypb.Empty, error)
}
RuntimeServiceHandler is an implementation of the otterscale.runtime.v1.RuntimeService service.
type ScaleRequest ¶
type ScaleRequest struct {
XXX_raceDetectHookData protoimpl.RaceDetectHookData
XXX_presence [1]uint32
// contains filtered or unexported fields
}
ScaleRequest defines the parameters for scaling a workload. Uses the Kubernetes /scale subresource for correctness.
func (*ScaleRequest) ClearCluster ¶
func (x *ScaleRequest) ClearCluster()
func (*ScaleRequest) ClearGroup ¶
func (x *ScaleRequest) ClearGroup()
func (*ScaleRequest) ClearName ¶
func (x *ScaleRequest) ClearName()
func (*ScaleRequest) ClearNamespace ¶
func (x *ScaleRequest) ClearNamespace()
func (*ScaleRequest) ClearReplicas ¶
func (x *ScaleRequest) ClearReplicas()
func (*ScaleRequest) ClearResource ¶
func (x *ScaleRequest) ClearResource()
func (*ScaleRequest) ClearVersion ¶
func (x *ScaleRequest) ClearVersion()
func (*ScaleRequest) GetCluster ¶
func (x *ScaleRequest) GetCluster() string
func (*ScaleRequest) GetGroup ¶
func (x *ScaleRequest) GetGroup() string
func (*ScaleRequest) GetName ¶
func (x *ScaleRequest) GetName() string
func (*ScaleRequest) GetNamespace ¶
func (x *ScaleRequest) GetNamespace() string
func (*ScaleRequest) GetReplicas ¶
func (x *ScaleRequest) GetReplicas() int32
func (*ScaleRequest) GetResource ¶
func (x *ScaleRequest) GetResource() string
func (*ScaleRequest) GetVersion ¶
func (x *ScaleRequest) GetVersion() string
func (*ScaleRequest) HasCluster ¶
func (x *ScaleRequest) HasCluster() bool
func (*ScaleRequest) HasGroup ¶
func (x *ScaleRequest) HasGroup() bool
func (*ScaleRequest) HasName ¶
func (x *ScaleRequest) HasName() bool
func (*ScaleRequest) HasNamespace ¶
func (x *ScaleRequest) HasNamespace() bool
func (*ScaleRequest) HasReplicas ¶
func (x *ScaleRequest) HasReplicas() bool
func (*ScaleRequest) HasResource ¶
func (x *ScaleRequest) HasResource() bool
func (*ScaleRequest) HasVersion ¶
func (x *ScaleRequest) HasVersion() bool
func (*ScaleRequest) ProtoMessage ¶
func (*ScaleRequest) ProtoMessage()
func (*ScaleRequest) ProtoReflect ¶
func (x *ScaleRequest) ProtoReflect() protoreflect.Message
func (*ScaleRequest) Reset ¶
func (x *ScaleRequest) Reset()
func (*ScaleRequest) SetCluster ¶
func (x *ScaleRequest) SetCluster(v string)
func (*ScaleRequest) SetGroup ¶
func (x *ScaleRequest) SetGroup(v string)
func (*ScaleRequest) SetName ¶
func (x *ScaleRequest) SetName(v string)
func (*ScaleRequest) SetNamespace ¶
func (x *ScaleRequest) SetNamespace(v string)
func (*ScaleRequest) SetReplicas ¶
func (x *ScaleRequest) SetReplicas(v int32)
func (*ScaleRequest) SetResource ¶
func (x *ScaleRequest) SetResource(v string)
func (*ScaleRequest) SetVersion ¶
func (x *ScaleRequest) SetVersion(v string)
func (*ScaleRequest) String ¶
func (x *ScaleRequest) String() string
type ScaleRequest_builder ¶
type ScaleRequest_builder struct {
// The target Kubernetes cluster identifier.
Cluster *string
// Kubernetes API Group (e.g., "apps").
Group *string
// Kubernetes API Version (e.g., "v1").
Version *string
// Kubernetes API Resource name in plural (e.g., "deployments").
Resource *string
// The namespace of the workload.
Namespace *string
// The name of the workload.
Name *string
// The desired number of replicas.
Replicas *int32
// contains filtered or unexported fields
}
func (ScaleRequest_builder) Build ¶
func (b0 ScaleRequest_builder) Build() *ScaleRequest
type ScaleResponse ¶
type ScaleResponse struct {
XXX_raceDetectHookData protoimpl.RaceDetectHookData
XXX_presence [1]uint32
// contains filtered or unexported fields
}
ScaleResponse contains the updated replica count after scaling.
func (*ScaleResponse) ClearReplicas ¶
func (x *ScaleResponse) ClearReplicas()
func (*ScaleResponse) GetReplicas ¶
func (x *ScaleResponse) GetReplicas() int32
func (*ScaleResponse) HasReplicas ¶
func (x *ScaleResponse) HasReplicas() bool
func (*ScaleResponse) ProtoMessage ¶
func (*ScaleResponse) ProtoMessage()
func (*ScaleResponse) ProtoReflect ¶
func (x *ScaleResponse) ProtoReflect() protoreflect.Message
func (*ScaleResponse) Reset ¶
func (x *ScaleResponse) Reset()
func (*ScaleResponse) SetReplicas ¶
func (x *ScaleResponse) SetReplicas(v int32)
func (*ScaleResponse) String ¶
func (x *ScaleResponse) String() string
type ScaleResponse_builder ¶
type ScaleResponse_builder struct {
// The current number of replicas after the scale operation.
Replicas *int32
// contains filtered or unexported fields
}
func (ScaleResponse_builder) Build ¶
func (b0 ScaleResponse_builder) Build() *ScaleResponse
type UnimplementedRuntimeServiceHandler ¶
type UnimplementedRuntimeServiceHandler struct{}
UnimplementedRuntimeServiceHandler returns CodeUnimplemented from all methods.
func (UnimplementedRuntimeServiceHandler) ExecuteTTY ¶
func (UnimplementedRuntimeServiceHandler) ExecuteTTY(context.Context, *ExecuteTTYRequest, *connect.ServerStream[ExecuteTTYResponse]) error
func (UnimplementedRuntimeServiceHandler) PodLog ¶
func (UnimplementedRuntimeServiceHandler) PodLog(context.Context, *PodLogRequest, *connect.ServerStream[PodLogResponse]) error
func (UnimplementedRuntimeServiceHandler) PortForward ¶
func (UnimplementedRuntimeServiceHandler) PortForward(context.Context, *PortForwardRequest, *connect.ServerStream[PortForwardResponse]) error
func (UnimplementedRuntimeServiceHandler) ResizeTTY ¶
func (UnimplementedRuntimeServiceHandler) ResizeTTY(context.Context, *ResizeTTYRequest) (*emptypb.Empty, error)
func (UnimplementedRuntimeServiceHandler) Restart ¶
func (UnimplementedRuntimeServiceHandler) Restart(context.Context, *RestartRequest) (*emptypb.Empty, error)
func (UnimplementedRuntimeServiceHandler) Scale ¶
func (UnimplementedRuntimeServiceHandler) Scale(context.Context, *ScaleRequest) (*ScaleResponse, error)
func (UnimplementedRuntimeServiceHandler) WritePortForward ¶
func (UnimplementedRuntimeServiceHandler) WritePortForward(context.Context, *WritePortForwardRequest) (*emptypb.Empty, error)
func (UnimplementedRuntimeServiceHandler) WriteTTY ¶
func (UnimplementedRuntimeServiceHandler) WriteTTY(context.Context, *WriteTTYRequest) (*emptypb.Empty, error)
type WritePortForwardRequest ¶
type WritePortForwardRequest struct {
XXX_raceDetectHookData protoimpl.RaceDetectHookData
XXX_presence [1]uint32
// contains filtered or unexported fields
}
WritePortForwardRequest sends data to an active port-forward session.
func (*WritePortForwardRequest) ClearData ¶
func (x *WritePortForwardRequest) ClearData()
func (*WritePortForwardRequest) ClearSessionId ¶
func (x *WritePortForwardRequest) ClearSessionId()
func (*WritePortForwardRequest) GetData ¶
func (x *WritePortForwardRequest) GetData() []byte
func (*WritePortForwardRequest) GetSessionId ¶
func (x *WritePortForwardRequest) GetSessionId() string
func (*WritePortForwardRequest) HasData ¶
func (x *WritePortForwardRequest) HasData() bool
func (*WritePortForwardRequest) HasSessionId ¶
func (x *WritePortForwardRequest) HasSessionId() bool
func (*WritePortForwardRequest) ProtoMessage ¶
func (*WritePortForwardRequest) ProtoMessage()
func (*WritePortForwardRequest) ProtoReflect ¶
func (x *WritePortForwardRequest) ProtoReflect() protoreflect.Message
func (*WritePortForwardRequest) Reset ¶
func (x *WritePortForwardRequest) Reset()
func (*WritePortForwardRequest) SetData ¶
func (x *WritePortForwardRequest) SetData(v []byte)
func (*WritePortForwardRequest) SetSessionId ¶
func (x *WritePortForwardRequest) SetSessionId(v string)
func (*WritePortForwardRequest) String ¶
func (x *WritePortForwardRequest) String() string
type WritePortForwardRequest_builder ¶
type WritePortForwardRequest_builder struct {
// The session identifier returned in the first PortForwardResponse.
SessionId *string
// Data to send to the forwarded port on the pod.
Data []byte
// contains filtered or unexported fields
}
func (WritePortForwardRequest_builder) Build ¶
func (b0 WritePortForwardRequest_builder) Build() *WritePortForwardRequest
type WriteTTYRequest ¶
type WriteTTYRequest struct {
XXX_raceDetectHookData protoimpl.RaceDetectHookData
XXX_presence [1]uint32
// contains filtered or unexported fields
}
WriteTTYRequest sends stdin data to an active exec session.
func (*WriteTTYRequest) ClearSessionId ¶
func (x *WriteTTYRequest) ClearSessionId()
func (*WriteTTYRequest) ClearStdin ¶
func (x *WriteTTYRequest) ClearStdin()
func (*WriteTTYRequest) GetSessionId ¶
func (x *WriteTTYRequest) GetSessionId() string
func (*WriteTTYRequest) GetStdin ¶
func (x *WriteTTYRequest) GetStdin() []byte
func (*WriteTTYRequest) HasSessionId ¶
func (x *WriteTTYRequest) HasSessionId() bool
func (*WriteTTYRequest) HasStdin ¶
func (x *WriteTTYRequest) HasStdin() bool
func (*WriteTTYRequest) ProtoMessage ¶
func (*WriteTTYRequest) ProtoMessage()
func (*WriteTTYRequest) ProtoReflect ¶
func (x *WriteTTYRequest) ProtoReflect() protoreflect.Message
func (*WriteTTYRequest) Reset ¶
func (x *WriteTTYRequest) Reset()
func (*WriteTTYRequest) SetSessionId ¶
func (x *WriteTTYRequest) SetSessionId(v string)
func (*WriteTTYRequest) SetStdin ¶
func (x *WriteTTYRequest) SetStdin(v []byte)
func (*WriteTTYRequest) String ¶
func (x *WriteTTYRequest) String() string
type WriteTTYRequest_builder ¶
type WriteTTYRequest_builder struct {
// The session identifier returned in the first ExecuteTTYResponse.
SessionId *string
// Stdin data to write.
Stdin []byte
// contains filtered or unexported fields
}
func (WriteTTYRequest_builder) Build ¶
func (b0 WriteTTYRequest_builder) Build() *WriteTTYRequest